==> haskell-case-insensitive-1.2.0.7-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.7
id: case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
key: case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: 3192e9625856825201eef0d072814261
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/case-insensitive-1.2.0.7
hs-libraries: HScase-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.0.7-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.7
id: case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
key: case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: 2d3b05d1ab8d1c87b1967f9544d81af7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/case-insensitive-1.2.0.7
hs-libraries: HScase-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
